pub struct CommandHistoryRecord {
pub id: String,
pub mutation_scope: String,
pub state: CommandHistoryState,
pub entries: Vec<CommandHistoryEntry>,
pub client_commit_id: String,
pub undo_client_commit_id: Option<String>,
pub redo_client_commit_id: Option<String>,
pub created_at: i64,
pub updated_at: i64,
}Fields
id: Stringmutation_scope: Stringstate: CommandHistoryStateentries: Vec<CommandHistoryEntry>client_commit_id: Stringundo_client_commit_id: Option<String>redo_client_commit_id: Option<String>created_at: i64updated_at: i64Trait Implementations
Sourceimpl Clone for CommandHistoryRecord
impl Clone for CommandHistoryRecord
Sourcefn clone(&self) -> CommandHistoryRecord
fn clone(&self) -> CommandHistoryRecord
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CommandHistoryRecord
impl Debug for CommandHistoryRecord
Sourceimpl<'de> Deserialize<'de> for CommandHistoryRecord
impl<'de> Deserialize<'de> for CommandHistoryRecord
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<CommandHistoryRecord, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<CommandHistoryRecord, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for CommandHistoryRecord
impl PartialEq for CommandHistoryRecord
Sourcefn eq(&self, other: &CommandHistoryRecord) -> bool
fn eq(&self, other: &CommandHistoryRecord) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for CommandHistoryRecord
impl Serialize for CommandHistoryRecord
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl TryFrom<CommandHistoryRow> for CommandHistoryRecord
impl TryFrom<CommandHistoryRow> for CommandHistoryRecord
Sourcetype Error = SyncularError
type Error = SyncularError
The type returned in the event of a conversion error.
Sourcefn try_from(
row: CommandHistoryRow,
) -> Result<CommandHistoryRecord, SyncularError>
fn try_from( row: CommandHistoryRow, ) -> Result<CommandHistoryRecord, SyncularError>
Performs the conversion.
impl StructuralPartialEq for CommandHistoryRecord